@@ -6,6 +6,7 @@ except pkg_resources.DistributionNotFound:
     # read the doc does not support poetry
     pass
 
+from .domain.exceptions import HTTPError, TimeoutError
 from .domain.model import (
     CollectionIterator,
     HeaderField,
@@ -16,7 +17,6 @@ from .domain.model import (
     Response,
     ResponseBox,
 )
-from .domain.exceptions import HTTPError, TimeoutError 
 from .domain.registry import register
 from .domain.scanner import scan
 from .middleware import (
@@ -32,3 +32,29 @@ from .sd.adapters.consul import ConsulDiscovery
 from .sd.adapters.router import RouterDiscovery
 from .sd.adapters.static import StaticDiscovery
 from .service.client import ClientFactory
+
+__all__ = [
+    "CircuitBreaker",
+    "ClientFactory",
+    "CollectionIterator",
+    "ConsulDiscovery",
+    "HeaderField",
+    "HTTPAddHeadersMiddleware",
+    "HTTPAuthorization",
+    "HTTPBearerAuthorization",
+    "HTTPError",
+    "HTTPMiddleware",
+    "Middleware",
+    "PathInfoField",
+    "PostBodyField",
+    "PrometheusMetrics",
+    "QueryStringField",
+    "register",
+    "Request",
+    "Response",
+    "ResponseBox",
+    "RouterDiscovery",
+    "scan",
+    "StaticDiscovery",
+    "TimeoutError",
+]
